window.Gleam.initSearch([{"doc":"ieee_float","title":"ieee_float","content":"# Gleam IEEE Float\n\nThis Gleam library provides an `IEEEFloat` type that is compliant with the IEEE\n754 standard for floating point arithmetic.\n\n[![Package Version](https://img.shields.io/hexpm/v/ieee_float)](https://hex.pm/packages/ieee_float)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/ieee_float/)\n![Erlang Compatible](https://img.shields.io/badge/target-erlang-a90432)\n![JavaScript Compatible](https://img.shields.io/badge/target-javascript-f3e155)\n\n## Background\n\nErlang&#39;s native float data type does not support infinity and NaN values. This\nlibrary fills that gap when such values need to be able to be represented and\nworked with.\n\nOn the JavaScript target, an `IEEEFloat` is simply a `number` because JavaScript\nnatively implements the IEEE 754 standard.\n\n## Usage\n\nAdd this library to your project:\n\n```sh\ngleam add ieee_float\n```\n\nAPI documentation can be found at &lt;https://hexdocs.pm/ieee_float/&gt;.\n\nThe following code demonstrates commonly used functionality of this library.\n\n```gleam\nimport ieee_float.{finite}\n\npub fn main() {\n  // Create finite values\n  let zero = finite(0.0)\n  let one = finite(1.0)\n  let two = finite(2.0)\n  let three = finite(3.0)\n\n  // Create infinity and NaN values\n  let positive_inf = ieee_float.positive_infinity()\n  let negative_inf = ieee_float.negative_infinity()\n  let nan = ieee_float.nan()\n\n  // Check whether a value is finite or NaN\n  let assert False = ieee_float.is_finite(positive_inf)\n  let assert True = ieee_float.is_nan(nan)\n\n  // Convert to a finite value of type `Float`. If the IEEE float is not\n  // finite then an error is returned.\n  let assert Ok(1.0) = ieee_float.to_finite(one)\n  let assert Error(Nil) = ieee_float.to_finite(positive_inf)\n\n  // Convert a value to raw bytes\n  let assert &lt;&lt;0x3F, 0x80, 0x00, 0x00&gt;&gt; = ieee_float.to_bytes_32_be(one)\n\n  // Create a value from raw bytes\n  let assert True =\n    ieee_float.from_bytes_32_be(&lt;&lt;0x3F, 0x80, 0x00, 0x00&gt;&gt;) == one\n\n  // Perform math operations\n  let assert True = ieee_float.add(two, three) == finite(5.0)\n  let assert True = ieee_float.divide(one, two) == finite(0.5)\n  let assert True = ieee_float.multiply(two, three) == finite(6.0)\n  let assert True = ieee_float.subtract(three, one) == finite(2.0)\n\n  // Perform math operations not supported by Erlang floats\n  let assert True = ieee_float.add(one, positive_inf) == positive_inf\n  let assert True =\n    ieee_float.add(positive_inf, negative_inf) |&gt; ieee_float.is_nan\n\n  let assert True = ieee_float.multiply(positive_inf, two) == positive_inf\n  let assert True =\n    ieee_float.multiply(negative_inf, positive_inf) == negative_inf\n\n  let assert True = ieee_float.divide(two, zero) == positive_inf\n  let assert True =\n    ieee_float.divide(positive_inf, positive_inf) |&gt; ieee_float.is_nan\n}\n```\n\n### Erlang Version\n\nUse Erlang 27 or later for the best IEEE 754 compliance. Earlier Erlang versions\nwill work for the vast majority of use cases, but operations involving or\nreturning negative zero may return non-compliant results.\n\n## License\n\nThis library is published under the MIT license, a copy of which is included.\n","url":"index.html"},{"doc":"ieee_float","title":"IEEEFloat","content":"pub opaque type IEEEFloat\n An IEEE 754 compliant floating point value that can be either a finite\n number, positive infinity, negative infinity, or NaN (not a number).\n\n On the JavaScript target, an `IEEEFloat` is a `number`.\n\n\nSynonyms:\nieee_float.IEEEFloat\nieee_float IEEEFloat","url":"ieee_float.html#IEEEFloat"},{"doc":"ieee_float","title":"absolute_value","content":"pub fn absolute_value(f: IEEEFloat) -&gt; IEEEFloat\n Returns the absolute value of an `IEEEFloat`.\n\nSynonyms:\nieee_float.absolute_value\nieee_float absolute_value","url":"ieee_float.html#absolute_value"},{"doc":"ieee_float","title":"add","content":"pub fn add(a: IEEEFloat, b: IEEEFloat) -&gt; IEEEFloat\n Adds two `IEEEFloat`s together.\n\nSynonyms:\nieee_float.add\nieee_float add","url":"ieee_float.html#add"},{"doc":"ieee_float","title":"ceiling","content":"pub fn ceiling(f: IEEEFloat) -&gt; IEEEFloat\n Rounds an `IEEEFloat` to the next highest whole number.\n\nSynonyms:\nieee_float.ceiling\nieee_float ceiling","url":"ieee_float.html#ceiling"},{"doc":"ieee_float","title":"clamp","content":"pub fn clamp(\n  f: IEEEFloat,\n  min min_bound: IEEEFloat,\n  max max_bound: IEEEFloat,\n) -&gt; IEEEFloat\n Restricts an `IEEEFloat` between a lower and upper bound.\n\nSynonyms:\nieee_float.clamp\nieee_float clamp","url":"ieee_float.html#clamp"},{"doc":"ieee_float","title":"compare","content":"pub fn compare(\n  a: IEEEFloat,\n  with b: IEEEFloat,\n) -&gt; Result(Order, Nil)\n Compares two `IEEEFloat`s, returning an `Order`: `Lt` for lower than, `Eq`\n for equals, or `Gt` for greater than. If either value is NaN then\n `Error(Nil)` is returned.\n\nSynonyms:\nieee_float.compare\nieee_float compare","url":"ieee_float.html#compare"},{"doc":"ieee_float","title":"divide","content":"pub fn divide(a: IEEEFloat, b: IEEEFloat) -&gt; IEEEFloat\n Divides one `IEEEFloat` by another.\n\nSynonyms:\nieee_float.divide\nieee_float divide","url":"ieee_float.html#divide"},{"doc":"ieee_float","title":"finite","content":"pub fn finite(f: Float) -&gt; IEEEFloat\n Creates a new `IEEEFloat` from a `Float`.\n\nSynonyms:\nieee_float.finite\nieee_float finite","url":"ieee_float.html#finite"},{"doc":"ieee_float","title":"floor","content":"pub fn floor(f: IEEEFloat) -&gt; IEEEFloat\n Rounds an `IEEEFloat` to the next lowest whole number.\n\nSynonyms:\nieee_float.floor\nieee_float floor","url":"ieee_float.html#floor"},{"doc":"ieee_float","title":"from_bytes_16_be","content":"pub fn from_bytes_16_be(bytes: BitArray) -&gt; IEEEFloat\n Converts bytes for a big endian 16-bit IEEE 754 float to an `IEEEFloat`.\n\n If the bit array doesn&#39;t contain exactly two bytes then NaN is returned.\n\nSynonyms:\nieee_float.from_bytes_16_be\nieee_float from_bytes_16_be","url":"ieee_float.html#from_bytes_16_be"},{"doc":"ieee_float","title":"from_bytes_16_le","content":"pub fn from_bytes_16_le(bytes: BitArray) -&gt; IEEEFloat\n Converts bytes for a little endian 16-bit IEEE 754 float to an `IEEEFloat`.\n\n If the bit array doesn&#39;t contain exactly two bytes then NaN is returned.\n\nSynonyms:\nieee_float.from_bytes_16_le\nieee_float from_bytes_16_le","url":"ieee_float.html#from_bytes_16_le"},{"doc":"ieee_float","title":"from_bytes_32_be","content":"pub fn from_bytes_32_be(bytes: BitArray) -&gt; IEEEFloat\n Converts bytes for a big endian 32-bit IEEE 754 float to an `IEEEFloat`.\n\n If the bit array doesn&#39;t contain exactly four bytes then NaN is returned.\n\nSynonyms:\nieee_float.from_bytes_32_be\nieee_float from_bytes_32_be","url":"ieee_float.html#from_bytes_32_be"},{"doc":"ieee_float","title":"from_bytes_32_le","content":"pub fn from_bytes_32_le(bytes: BitArray) -&gt; IEEEFloat\n Converts bytes for a little endian 32-bit IEEE 754 float to an `IEEEFloat`.\n\n If the bit array doesn&#39;t contain exactly four bytes then NaN is returned.\n\nSynonyms:\nieee_float.from_bytes_32_le\nieee_float from_bytes_32_le","url":"ieee_float.html#from_bytes_32_le"},{"doc":"ieee_float","title":"from_bytes_64_be","content":"pub fn from_bytes_64_be(bytes: BitArray) -&gt; IEEEFloat\n Converts bytes for a big endian 64-bit IEEE 754 float to an `IEEEFloat`.\n\n If the bit array doesn&#39;t contain exactly eight bytes then NaN is returned.\n\nSynonyms:\nieee_float.from_bytes_64_be\nieee_float from_bytes_64_be","url":"ieee_float.html#from_bytes_64_be"},{"doc":"ieee_float","title":"from_bytes_64_le","content":"pub fn from_bytes_64_le(bytes: BitArray) -&gt; IEEEFloat\n Converts bytes for a little endian 64-bit IEEE 754 float to an `IEEEFloat`.\n\n If the bit array doesn&#39;t contain exactly eight bytes then NaN is returned.\n\nSynonyms:\nieee_float.from_bytes_64_le\nieee_float from_bytes_64_le","url":"ieee_float.html#from_bytes_64_le"},{"doc":"ieee_float","title":"is_finite","content":"pub fn is_finite(f: IEEEFloat) -&gt; Bool\n Returns whether an `IEEEFloat` is finite. If it isn&#39;t finite it is either\n infinite or NaN.\n\nSynonyms:\nieee_float.is_finite\nieee_float is_finite","url":"ieee_float.html#is_finite"},{"doc":"ieee_float","title":"is_nan","content":"pub fn is_nan(f: IEEEFloat) -&gt; Bool\n Returns whether an `IEEEFloat` is NaN. If it isn&#39;t NaN it is either finite\n or infinite.\n\nSynonyms:\nieee_float.is_nan\nieee_float is_nan","url":"ieee_float.html#is_nan"},{"doc":"ieee_float","title":"max","content":"pub fn max(a: IEEEFloat, b: IEEEFloat) -&gt; IEEEFloat\n Compares two `IEEEFloat`s, returning the larger of the two.\n\nSynonyms:\nieee_float.max\nieee_float max","url":"ieee_float.html#max"},{"doc":"ieee_float","title":"min","content":"pub fn min(a: IEEEFloat, b: IEEEFloat) -&gt; IEEEFloat\n Compares two `IEEEFloat`s, returning the smaller of the two.\n\nSynonyms:\nieee_float.min\nieee_float min","url":"ieee_float.html#min"},{"doc":"ieee_float","title":"multiply","content":"pub fn multiply(a: IEEEFloat, b: IEEEFloat) -&gt; IEEEFloat\n Multiplies two `IEEEFloat`s together.\n\nSynonyms:\nieee_float.multiply\nieee_float multiply","url":"ieee_float.html#multiply"},{"doc":"ieee_float","title":"nan","content":"pub fn nan() -&gt; IEEEFloat\n Returns the NaN (Not a Number) value.\n\nSynonyms:\nieee_float.nan\nieee_float nan","url":"ieee_float.html#nan"},{"doc":"ieee_float","title":"negate","content":"pub fn negate(f: IEEEFloat) -&gt; IEEEFloat\n Returns the negative of an `IEEEFloat`.\n\nSynonyms:\nieee_float.negate\nieee_float negate","url":"ieee_float.html#negate"},{"doc":"ieee_float","title":"negative_infinity","content":"pub fn negative_infinity() -&gt; IEEEFloat\n Returns the negative infinity value.\n\nSynonyms:\nieee_float.negative_infinity\nieee_float negative_infinity","url":"ieee_float.html#negative_infinity"},{"doc":"ieee_float","title":"parse","content":"pub fn parse(s: String) -&gt; IEEEFloat\n Parses a string to an `IEEEFloat`. If the string is not a valid float then\n NaN is returned.\n\nSynonyms:\nieee_float.parse\nieee_float parse","url":"ieee_float.html#parse"},{"doc":"ieee_float","title":"positive_infinity","content":"pub fn positive_infinity() -&gt; IEEEFloat\n Returns the positive infinity value.\n\nSynonyms:\nieee_float.positive_infinity\nieee_float positive_infinity","url":"ieee_float.html#positive_infinity"},{"doc":"ieee_float","title":"power","content":"pub fn power(f: IEEEFloat, exp: IEEEFloat) -&gt; IEEEFloat\n Returns the results of the base being raised to the power of the exponent.\n\nSynonyms:\nieee_float.power\nieee_float power","url":"ieee_float.html#power"},{"doc":"ieee_float","title":"random","content":"pub fn random() -&gt; IEEEFloat\n Generates a random `IEEEFloat` between zero (inclusive) and one (exclusive).\n\n On the Erlang target this updates the random state in the process\n dictionary. See &lt;https://www.erlang.org/doc/man/rand.html#uniform-0&gt;.\n\nSynonyms:\nieee_float.random\nieee_float random","url":"ieee_float.html#random"},{"doc":"ieee_float","title":"round","content":"pub fn round(f: IEEEFloat) -&gt; Result(Int, Nil)\n Rounds an `IEEEFloat` to the nearest whole number as an `Int`. If the input\n value is not finite then `Error(Nil)` is returned.\n\nSynonyms:\nieee_float.round\nieee_float round","url":"ieee_float.html#round"},{"doc":"ieee_float","title":"square_root","content":"pub fn square_root(f: IEEEFloat) -&gt; IEEEFloat\n Returns the square root of an `IEEEFloat`.\n\nSynonyms:\nieee_float.square_root\nieee_float square_root","url":"ieee_float.html#square_root"},{"doc":"ieee_float","title":"subtract","content":"pub fn subtract(a: IEEEFloat, b: IEEEFloat) -&gt; IEEEFloat\n Subtracts one `IEEEFloat` from another.\n\nSynonyms:\nieee_float.subtract\nieee_float subtract","url":"ieee_float.html#subtract"},{"doc":"ieee_float","title":"to_bytes_16_be","content":"pub fn to_bytes_16_be(f: IEEEFloat) -&gt; BitArray\n Converts an `IEEEFloat` to bytes for a big endian 16-bit IEEE 754 float.\n\nSynonyms:\nieee_float.to_bytes_16_be\nieee_float to_bytes_16_be","url":"ieee_float.html#to_bytes_16_be"},{"doc":"ieee_float","title":"to_bytes_16_le","content":"pub fn to_bytes_16_le(f: IEEEFloat) -&gt; BitArray\n Converts an `IEEEFloat` to bytes for a little endian 16-bit IEEE 754 float.\n\nSynonyms:\nieee_float.to_bytes_16_le\nieee_float to_bytes_16_le","url":"ieee_float.html#to_bytes_16_le"},{"doc":"ieee_float","title":"to_bytes_32_be","content":"pub fn to_bytes_32_be(f: IEEEFloat) -&gt; BitArray\n Converts an `IEEEFloat` to bytes for a big endian 32-bit IEEE 754 float.\n\nSynonyms:\nieee_float.to_bytes_32_be\nieee_float to_bytes_32_be","url":"ieee_float.html#to_bytes_32_be"},{"doc":"ieee_float","title":"to_bytes_32_le","content":"pub fn to_bytes_32_le(f: IEEEFloat) -&gt; BitArray\n Converts an `IEEEFloat` to bytes for a little endian 32-bit IEEE 754 float.\n\nSynonyms:\nieee_float.to_bytes_32_le\nieee_float to_bytes_32_le","url":"ieee_float.html#to_bytes_32_le"},{"doc":"ieee_float","title":"to_bytes_64_be","content":"pub fn to_bytes_64_be(f: IEEEFloat) -&gt; BitArray\n Converts an `IEEEFloat` to bytes for a big endian 64-bit IEEE 754 float.\n\nSynonyms:\nieee_float.to_bytes_64_be\nieee_float to_bytes_64_be","url":"ieee_float.html#to_bytes_64_be"},{"doc":"ieee_float","title":"to_bytes_64_le","content":"pub fn to_bytes_64_le(f: IEEEFloat) -&gt; BitArray\n Converts an `IEEEFloat` to bytes for a little endian 64-bit IEEE 754 float.\n\nSynonyms:\nieee_float.to_bytes_64_le\nieee_float to_bytes_64_le","url":"ieee_float.html#to_bytes_64_le"},{"doc":"ieee_float","title":"to_finite","content":"pub fn to_finite(f: IEEEFloat) -&gt; Result(Float, Nil)\n Converts an `IEEEFloat` to the native `Float` type. If the `IEEEFloat` is\n infinite or NaN then `Error(Nil)` is returned.\n\nSynonyms:\nieee_float.to_finite\nieee_float to_finite","url":"ieee_float.html#to_finite"},{"doc":"ieee_float","title":"to_string","content":"pub fn to_string(f: IEEEFloat) -&gt; String\n Formats an `IEEEFloat` as a string.\n\nSynonyms:\nieee_float.to_string\nieee_float to_string","url":"ieee_float.html#to_string"},{"doc":"ieee_float","title":"ieee_float","content":"","url":"ieee_float.html"}]);